@@ -177,7 +177,7 @@ class DaktelaDialerBackend(DialerBackend):
             # exception).
 
     def create_message(self, recipient, content=None, related_objects=None, tag=None, template=None,
-                       is_autodialer=True, **kwargs):
+                       is_autodialer=True, priority=settings.DEFAULT_MESSAGE_PRIORITY, **kwargs):
         """
         Create dialer message which will be logged in the database (content is not needed for this .
         :param recipient: phone number of the recipient
@@ -195,6 +195,7 @@ class DaktelaDialerBackend(DialerBackend):
                 template=template,
                 state=self.get_initial_dialer_state(recipient),
                 is_autodialer=is_autodialer,
+                priority=priority,
                 **kwargs,
                 **self._get_extra_message_kwargs()
             )
