@@ -1,4 +1,5 @@
 from chamber.shortcuts import change_and_save
+from django.utils import timezone
 
 from pymess.backend.sms import SMSBackend
 from pymess.models import OutputSMSMessage
@@ -10,4 +11,4 @@ class DummySMSBackend(SMSBackend):
     """
 
     def publish_message(self, message):
-        self._update_message_after_sending(message, state=OutputSMSMessage.STATE.DEBUG)
+        self._update_message_after_sending(message, state=OutputSMSMessage.STATE.DEBUG, sent_at=timezone.now())
