@@ -196,7 +196,7 @@ class SMSOperatorBackend(SMSBackend):
         except self.SMSOperatorSendingError as ex:
             self._update_message_after_sending_error(
                 message,
-                state=EmailMessage.STATE.ERROR,
+                state=OutputSMSMessage.STATE.ERROR,
                 error=str(ex)
             )
         except requests.exceptions.RequestException as ex:
