@@ -118,6 +118,9 @@ DEFAULTS = {
     'PUSH_NOTIFICATION_BATCH_MAX_NUMBER_OF_SEND_ATTEMPTS': 3,
     'PUSH_NOTIFICATION_BATCH_MAX_SECONDS_TO_SEND': 60 * 60,
     'PUSH_NOTIFICATION_RETRY_SENDING': True,
+
+    # General message settings
+    'DEFAULT_MESSAGE_PRIORITY': 3,
 }
 
 
